# archimedean

Sends email whenever there is new homework on Archie website. Can download all files from any class in CineMath. Can download any resource posted on Archie. 
Still in testing phase!

## Installation

    If you do not have Python installed, go to https://www.python.org/downloads/ 
    Then download the latest version of Python
    After installing, open terminal and 
    run 'python3 -m pip install archimedean'

    If you do have Python installed, then
    Open the terminal
    Run 'python3 -m pip install archimedean' to install

## Usage

    In the terminal, first run 'archimedean login' to save your credentials

    Commands:
      'archimedean homework' display current homework and due dates to the command line
      'archimedean cinemath' downloads all lessons from a class in CineMath
      'archimedean email' will send you an email every time there is new homework on Archie
      'archimedean birthdays' will display all upcoming birthdays for other students
      'archimedean resources' will display links for resources for a specified class on Archie
      'archimedean apes' will download specified chapters from APES class (made only for APES students)
      'archimedean schedule' will display your current class and what class you will have next

## Questions

    If you have any questions, feel free to email me at: 
    daniel.miami2005@gmail.com

## Github Docs

    The GitHub repository for this project is at https://github.com/BananaApache/archimedean
